{
  inputs = { fenix.url = "github:nix-community/fenix"; };

  outputs = { self, nixpkgs, flake-utils, fenix }:
    flake-utils.lib.eachDefaultSystem (system:
      let
        pkgs = import nixpkgs {
          inherit system;
          overlays = [ fenix.overlays.default ];
        };

        toolchain = pkgs.fenix.default;

        flakePkgs = rec { beng = pkgs.callPackage ./. { inherit toolchain; }; };
      in rec {
        packages = flake-utils.lib.flattenTree flakePkgs;
        defaultPackage = packages.beng;

        devShell = pkgs.mkShell {
          inputsFrom = with packages; [ beng ];

          packages = (with pkgs; [
            cargo-watch
            cargo-deny
            cargo-edit
            cargo-expand
            pijul

            # Get the nightly version of rustfmt so we can wrap comments
            pkgs.fenix.default.rustfmt
          ]) ++ (with toolchain; [ cargo clippy rustc rustfmt ]);
        };
      });
}
